summaryrefslogtreecommitdiffstats
path: root/ash/wm/workspace_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/wm/workspace_controller.h')
-rw-r--r--ash/wm/workspace_controller.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/ash/wm/workspace_controller.h b/ash/wm/workspace_controller.h
index a77863a..ba82e09 100644
--- a/ash/wm/workspace_controller.h
+++ b/ash/wm/workspace_controller.h
@@ -40,7 +40,10 @@ class ASH_EXPORT WorkspaceController
// Sets the active workspace based on |window|.
void SetActiveWorkspaceByWindow(aura::Window* window);
- // See description in BaseWorkspaceManager::GetParentForNewWindow().
+ // Returns the container window for the active workspace, never NULL.
+ aura::Window* GetActiveWorkspaceWindow();
+
+ // See description in WorkspaceManager::GetParentForNewWindow().
aura::Window* GetParentForNewWindow(aura::Window* window);
// Starts the animation that occurs on first login.